from django.db import models
 
class Campaign(models.Model):
    name = models.CharField(max_length=255)
    start_date = models.DateField()
    end_date = models.DateField()
    target_audience = models.CharField(max_length=255)
    channels = models.CharField(max_length=255)
    budget = models.DecimalField(max_digits=10, decimal_places=2)
    objectives = models.TextField()
    assets = models.FileField(upload_to='campaign_assets/', null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True)  # Set when the object is created
    updated_at = models.DateTimeField(auto_now=True)  # Set on every save of the object
    assigned_to = models.ForeignKey("account.Account", on_delete=models.SET_NULL, null=True, blank=True,
                                    related_name='assigned_campaigns')

    def get_conversion_rate(self):
        """
        Calculate the conversion rate for the campaign.

        Conversion rate = (Number of Converted Leads / Total Leads) * 100
        """
        total_leads = self.leads.count()
        print(total_leads)
        
        converted_leads = self.leads.filter(status__iexact='converted').count()  # Case-insensitive match
        print(converted_leads)

        if total_leads == 0:
            return 0  # Avoid division by zero

        conversion_rate = (converted_leads / total_leads) * 100
        return round(conversion_rate, 2)  # Round to two decimal places for better readability

    def __str__(self):
        return self.name


class Interaction(models.Model):
    campaign = models.ForeignKey(Campaign, on_delete=models.CASCADE, related_name='interactions')
    clicks = models.IntegerField(default=0)
    impressions = models.IntegerField(default=0)
    conversions = models.IntegerField(default=0)

    def __str__(self):
        return f"{self.campaign.name} - Interactions"


from django.db import models

class Lead(models.Model):
    STATUS_CHOICES = [
        ('new', 'New'),
        ('contacted', 'Contacted'),
        ('qualified', 'Qualified'),
        ('lost', 'Lost'),
        ('converted', 'Converted'),
        ('not_serviceable', 'Not Serviceable'),
    ]
    
    campaign = models.ForeignKey(Campaign, on_delete=models.CASCADE, related_name='leads', null=True, blank=True)
    name = models.CharField(max_length=255, null=True, blank=True)
    phone_number = models.CharField(max_length=20, null=True, blank=True)
    product_type = models.CharField(max_length=255, null=True, blank=True)
    comments = models.TextField(null=True, blank=True)
    location = models.CharField(max_length=255, null=True, blank=True)
    status = models.CharField(max_length=20, choices=STATUS_CHOICES, default='new', null=True, blank=True)
    created_at = models.DateTimeField(auto_now_add=True, null=True, blank=True)
    updated_at = models.DateTimeField(auto_now=True, null=True, blank=True)
    assigned_to = models.ForeignKey("account.Account", on_delete=models.SET_NULL, null=True, blank=True, related_name='assigned_sales')
    next_follow_up_date = models.DateField(null=True, blank=True, verbose_name="Next Follow Up Date")

    def __str__(self):
        return f"{self.name} - {self.status}"

